<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  version="1.0">


  <xsl:output method="html" encoding="iso-8859-1"
  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"/>


  <xsl:template match="lodju-archive">
    <xsl:for-each select="folder">
      <xsl:call-template name="make-folder-page"/>
    </xsl:for-each>
    <xsl:apply-templates/>
    <xsl:call-template name="make-contents-map"/>
  </xsl:template>


  <xsl:template match="folder[.//image/privacy/@level='public']">
    <xsl:variable name="folder-path">
      <xsl:call-template name="make-folder-path"/>
    </xsl:variable>

    <xsl:document href="{$folder-path}" method="html" encoding="iso-8859-1"
		  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN">
      <xsl:call-template name="make-folder-page"/>
    </xsl:document>

    <xsl:apply-templates/>
  </xsl:template>


  <xsl:template name="make-folder-page">
    <html>
      <xsl:call-template name="layout-index-head"/>
      <body>
	<xsl:call-template name="layout-index-header"/>
	<xsl:call-template name="layout-folder-and-image-list"/>
	<xsl:call-template name="layout-index-footer"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="image[privacy/@level='public']">
    <xsl:variable name="image-page-path">
      <xsl:value-of select="concat(generate-id(), '.html')"/>
    </xsl:variable>
    
    <xsl:document href="{$image-page-path}" method="html" 
    	          encoding="iso-8859-1"
		  doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN">
      <html>
	<xsl:call-template name="layout-image-head"/>
	<body bgcolor="#ffffff" text="#000000" link="c10000">
	  <center>
	    <xsl:call-template name="layout-image-header"/>
	    <xsl:call-template name="layout-image-picture"/>
	    <xsl:call-template name="layout-image-footer"/>
    	  </center>
	</body>
      </html>
    </xsl:document>
  </xsl:template>
  

  <xsl:template name="make-folder-path">
    <xsl:value-of select="generate-id(.)"/>
    <xsl:text>.html</xsl:text>
  </xsl:template>


  <xsl:template name="make-image-path">
    <xsl:text>-</xsl:text>
    <xsl:value-of select="generate-id(.)"/>
    <xsl:text>.jpg</xsl:text>
  </xsl:template>


  <xsl:template name="make-contents-map">
    <!-- Strange workaround to get the map into the output dir -->
    <xsl:variable name="contents">contents.map</xsl:variable>
    
    <xsl:document href="{$contents}"
      method="text"
      omit-xml-declaration="yes">

      <xsl:for-each select="//image[privacy/@level='public']">
	<xsl:value-of select="filespec/@uri"/><xsl:text> 0</xsl:text>
	<xsl:value-of select="rotation"/><xsl:text> </xsl:text>
	<xsl:call-template 
	  name="make-image-path"/>
	<xsl:text>
</xsl:text>
      </xsl:for-each>
    </xsl:document>
    
  </xsl:template>


  <xsl:template match="*"/>


  <xsl:template name="layout-index-head">
    <head>
      <title><xsl:value-of select="name"/></title>
      <link rel="stylesheet" href="lodju.css" type="text/css"/>
    </head>
  </xsl:template>


  <xsl:template name="layout-index-header">
    <table width="90%" border="0" cellpadding="0" cellspacing="0" 
           bgcolor="#ffffff">
      <tr>
	<td align="left" valign="bottom">
	    <img src="logo_top.gif" alt="Logo top" border="0"/>
	</td>
	<td></td>
      </tr>
      <tr>
	<td align="left" background="fade_bg.gif">
	    <img src="logo_middle.gif" border="0" alt="Logo middle"/>
	</td>
	<td align="right" background="fade.gif">
	    <span class="title">
	    	<xsl:value-of select="name"/>
	    </span>
	</td>
      </tr>
      <tr>
	<td align="left" valign="top">
	    <img src="logo_bottom.gif" border="0" alt="Logot bottom"/>
	</td>
	<td align="right">
	  <xsl:call-template name="folder-links"/>
	</td>
      </tr>
    </table>
  </xsl:template>
  
  
  <xsl:template name="folder-links">
    <xsl:call-template name="folder-link-previous"/>
    <xsl:text> </xsl:text>
    <xsl:if test="../../folder">
      <a href="{concat(generate-id(..), '.html')}">Up</a>
    </xsl:if>
    <xsl:text> </xsl:text>
<!--
    <xsl:text> | </xsl:text>
-->
    <xsl:call-template name="folder-link-next"/>
  </xsl:template>
  
  
  <xsl:template name="folder-link-previous">
    <xsl:if test="preceding-sibling::folder[.//image/privacy/@level='public']">
      <xsl:for-each select="preceding-sibling::folder[.//image/privacy/@level='public']">
	<xsl:if test="position() = last()">
	  <a>
	    <xsl:attribute name="href">
	      <xsl:value-of select="concat(generate-id(.),'.html')"/>
	    </xsl:attribute>
	    <xsl:text>&lt;&lt; Previous</xsl:text>
	  </a>
	</xsl:if>
      </xsl:for-each>
    </xsl:if>
  </xsl:template>
  

  <xsl:template name="folder-link-next">
    <xsl:if test="following-sibling::folder[.//image/privacy/@level='public']">
      <a>
	<xsl:attribute name="href">
	  <xsl:value-of 
	    select="concat(
	      generate-id(following::folder[.//image/privacy/@level='public']),
	      '.html')"/>
	</xsl:attribute>
	<xsl:text>Next &gt;&gt;</xsl:text>
      </a>
    </xsl:if>
  </xsl:template>


  <xsl:template name="layout-index-footer">
    <br clear="all"/>
    <table width="90%" border="0" cellpadding="0" cellspacing="0" 
           bgcolor="#ffffff">
      <tr>
	<td colspan="2">
	  <xsl:call-template name="folder-links"/>
	</td>
      </tr>
      <tr>
	<td background="footerfill.gif" width="20%">
	  <img src="clear.gif" width="1" height="9" alt=""/>
	</td>
	<td background="footerfade.gif" align="right">
	  <img src="clear.gif" width="1" height="9" alt=""/>
	</td>
      </tr>
    </table>
  </xsl:template>


  <xsl:template name="layout-image-head">
    <head>
      <title><xsl:value-of select="title"/></title>
      <link rel="stylesheet" href="lodju.css" type="text/css"/>
    </head>
  </xsl:template>
  

  <xsl:template name="layout-image-header">
    <table width="90%" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
      <tr>
	<td align="left" valign="bottom">
	  <img src="logo_top.gif" alt="Logo top" border="0"/>
	</td>
	<td></td>
      </tr>
      <tr>
	<td align="left" background="fade_bg.gif">
	  <img src="logo_middle.gif" border="0" alt="Logo middle"/>
	</td>
	<td align="right" background="fade.gif">
	  <span class="title">
	    <xsl:value-of select="../name"/>
	  </span>
	</td>
      </tr>
      <tr>
	<td align="left" valign="top">
	  <img src="logo_bottom.gif" border="0" alt="Logo bottom"/>
	</td>
	<td align="right">
	  <xsl:call-template name="image-links"/>
	</td>
      </tr>
    </table>
  </xsl:template>
  
  
  <xsl:template name="image-links">
    <xsl:call-template name="image-link-previous"/>
    <xsl:text> </xsl:text>
    <a href="{concat(generate-id(..), '.html')}">Up</a>
    <xsl:text> </xsl:text>
    <xsl:call-template name="image-link-next"/>
  </xsl:template>
  
  
  <xsl:template name="image-link-previous">
    <xsl:if test="preceding-sibling::image[privacy/@level='public']">
      <xsl:for-each select="preceding::image[privacy/@level='public']">
	<xsl:if test="position() = last()">
	  <a>
	    <xsl:attribute name="href">
	      <xsl:value-of select="concat(generate-id(.),'.html')"/>
	    </xsl:attribute>
	    <xsl:text>&lt;&lt; Previous</xsl:text>
	  </a>
	</xsl:if>
      </xsl:for-each>
    </xsl:if>
  </xsl:template>
  

  <xsl:template name="image-link-next">
    <xsl:if test="following-sibling::image[privacy/@level='public']">
      <a>
	<xsl:attribute name="href">
	  <xsl:value-of 
	    select="concat(
	      generate-id(following::image[privacy/@level='public']),
	      '.html')"/>
	</xsl:attribute>
	<xsl:text>Next &gt;&gt;</xsl:text>
      </a>
    </xsl:if>
  </xsl:template>
  

  <xsl:template name="layout-image-picture">
    <table width="85%" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
      <tr>
	<td>
	  <p> </p>
	  <img border="0">
	    <xsl:attribute name="alt">
	      <xsl:value-of select="title"/>
	    </xsl:attribute>
	    <xsl:attribute name="src">
	      <xsl:value-of select="concat('medium-', generate-id(), '.jpg')"/>
<!--
	      <xsl:text>foo-big.jpg</xsl:text>
-->
	    </xsl:attribute>
	  </img>
	</td>
      </tr>
      <tr>
	<td>
	  <xsl:value-of select="title"/>
	  <p> </p>
	</td>
      </tr>
    </table>
  </xsl:template>


  <xsl:template name="layout-image-footer">
    <br clear="all"/>
    <table width="90%" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
      <tr>
	<td colspan="2">
	  <xsl:call-template name="image-links"/>
	</td>
      </tr>
      <tr>
	<td background="footerfill.gif" width="20%">
	  <img src="clear.gif" width="1" height="9" alt=""/>
	</td>
	<td background="footerfade.gif" align="right">
	  <img src="clear.gif" width="1" height="9" alt=""/>
	</td>
      </tr>
    </table>
  </xsl:template>


  <xsl:template name="layout-folder-and-image-list">
    <xsl:for-each select="./folder[.//image/privacy/@level='public']">
      <xsl:variable name="index-path">
	<xsl:call-template name="make-folder-path"/>
      </xsl:variable>

      <table border="0" cellpadding="0" cellspacing="20" 
	     bgcolor="#ffffff" align="left">
    	<tr>
	    <td>
	      <a href="{$index-path}">
		<img src="image_folder.gif" alt="{name}" 
		     width="120" height="60" border="0"/>
	      </a>
	    </td>
	</tr>
    	<tr>
	    <td>
	      <a href="{$index-path}">
		<xsl:value-of select="name"/>
	      </a>
	    </td>
	</tr>
      </table>
      
      <xsl:if test="round(position() div 4) * 4 = position()">
      	<br clear="all"/>
      </xsl:if>
    </xsl:for-each>

    <xsl:for-each select="./image[privacy/@level='public']">
      <xsl:variable name="index-path">
	<xsl:call-template name="make-folder-path"/>
      </xsl:variable>

      <table border="0" cellpadding="0" cellspacing="20" 
	     bgcolor="#ffffff" align="left">
    	<tr>
	    <td width="105" height="105" align="left" valign="bottom">
	      <a>
		<xsl:attribute name="href">
		  <xsl:value-of select="concat(generate-id(), '.html')"/>
		</xsl:attribute>
		<img>
		  <xsl:attribute name="src">
<!--
		    <xsl:text>no_thumb.gif</xsl:text>
-->
		    <xsl:text>thumb</xsl:text>
		    <xsl:call-template name="make-image-path"/>
		  </xsl:attribute>
		  <xsl:attribute name="alt">
		    <xsl:value-of select="title"/>
		  </xsl:attribute>
		</img>
	      </a>
	    </td>
	</tr>
    	<tr>
	    <td width="105">
	      <a>
		<xsl:attribute name="href">
		  <xsl:value-of select="concat(generate-id(), '.html')"/>
		</xsl:attribute>
		<xsl:value-of select="title"/>
	      </a>
	    </td>
	</tr>
      </table>
      
      <xsl:if test="round(position() div 4) * 4 = position()">
      	<br clear="all"/>
      </xsl:if>
    </xsl:for-each>

    <br clear="all"/>
  </xsl:template>

</xsl:stylesheet>
